@@ -62,17 +62,38 @@
 #' - `print()`: prints a single result, by default the first converted rate.
 #' Others can be printed by passing the `pos` input. e.g. `print(x, pos = 2)`
 #'
-#' - `summary()`: prints summary table of all converted rates and metadata, or
-#' those specified by the `pos` input. e.g. `summary(x, pos = 1:5)`. The summary
-#' can be exported as a separate dataframe by passing `export = TRUE`.
+#' - `summary()`: prints a condensed version of the output `$summary` table of
+#' converted rates and metadata. Specific rows can be specified with the `pos`
+#' input. e.g. `summary(x, pos = 1:5)`. This can be exported as a separate data
+#' frame by passing `export = TRUE`. This will be the *full* summary table, not
+#' the one printed to the console, including all rate parameters, data
+#' locations, adjustments if applied, units, and more. Note, the summary table
+#' contains linear regression coefficients alongside other metadata. These
+#' should not be confused with those in other functions such as `calc_rate`
+#' where slopes represent rates and coefficients such as a high r-squared are
+#' important. Here, slope represents the stability of the data region, in that
+#' the closer the slope is to zero, the less the delta oxygen values in that
+#' region vary, which is an indication of a region of stable rates. They are
+#' included to enable possible future functionality where stable regions may be
+#' automatically identified, and should generally be ignored. However, advanced
+#' users can use regular R syntax to explore and subset the results using these
+#' if they wish.
 #'
 #' - `mean()`: calculates the mean of all converted rates, or those specified by
 #' the `pos` input. e.g. `mean(x, pos = 1:5)` The mean can be exported as a
 #' separate value by passing `export = TRUE`.
 #'
+#' ## More
+#'
+#' For additional help, documentation, vignettes, and more visit the `respR`
+#' website at <https://januarharianto.github.io/respR/>
+#'
 #' @return Output is a `list` object containing the `$rate.input`, and converted
 #'   rate(s) in `$rate.output` in the `$output.unit`, as well as inputs and
-#'   summary elements.
+#'   summary elements. Note, `$rate.abs` is the *absolute* rate in the output
+#'   unit minus the mass- or area-specific component. The `$summary` table
+#'   element contains all rate parameters and data locations (depending on what
+#'   class of object was entered), adjustments (if applied), units, and more.
 #'
 #' @param x numeric value or vector, or object of class [calc_rate.ft()] or
 #'   [adjust_rate.ft()]. Contains the rate(s) to be converted.
@@ -142,15 +163,39 @@ convert_rate.ft <- function(x,
 
   # Validate inputs ---------------------------------------------------------
 
+  # Create extended summary table
+  summ.ext <- data.table(rank = NA,
+                         intercept_b0 = NA,
+                         slope_b1 = NA,
+                         rsq = NA,
+                         row = NA,
+                         endrow = NA,
+                         time = NA,
+                         endtime = NA,
+                         oxy = NA,
+                         endoxy = NA,
+                         delta_mean = NA,
+                         flowrate = NA,
+                         rate = NA,
+                         adjustment = NA,
+                         rate.adjusted = NA)
+
   # Validate x
   if (is.numeric(x)) {
     rate <- x
+    summ.ext <- as.data.table(lapply(summ.ext, rep, length(rate)))
+    summ.ext$rank <- 1:length(rate)
+    summ.ext$rate <- rate
     message("convert_rate.ft: numeric input detected. Converting...")
   } else if ("calc_rate.ft" %in% class(x)) {
     rate <- x$rate
+    summ.ext <- x$summary
+    summ.ext$adjustment <- NA
+    summ.ext$rate.adjusted <- NA
     message("convert_rate.ft: object of class 'calc_rate.ft' detected. Converting '$rate' element.")
   } else if ("adjust_rate.ft" %in% class(x)) {
     rate <- x$rate.adjusted
+    summ.ext <- x$summary
     message("convert_rate.ft: object of class 'adjust_rate.ft' detected. Converting '$rate.adjusted' element.")
   } else stop("convert_rate.ft: 'x' must be an `calc_rate.ft` or `adjust_rate.ft` object, or a numeric value or vector.")
 
@@ -300,6 +345,7 @@ convert_rate.ft <- function(x,
                                     rate.a.spec = rate.a.spec,
                                     output.unit = output.unit,
                                     rate.output = VO2.out)
+  summary <- cbind(summ.ext, summary)
 
   out <- list(call = call,
               inputs = list(x = x,
@@ -370,12 +416,15 @@ summary.convert_rate.ft <- function(object, pos = NULL, export = FALSE, ...) {
     cat("\n")
     cat("\n")
   }
-  out <- cbind(rank = pos, object$summary[pos,])
+
+  out <- data.table(object$summary[pos, c(1,16:25), with=FALSE])
+  out_exp <- data.table(object$summary[pos,])
+
   print(out)
   cat("-----------------------------------------\n")
 
   if(export)
-    return(invisible(out)) else
+    return(invisible(out_exp)) else
       return(invisible(object))
 }
 
